@@ -1,5 +1,5 @@
 /*
-	Copyright (c) 2000-2011 Michael Pozhidaev<msp@altlinux.org>
+	Copyright (c) 2000-2012 Michael Pozhidaev<msp@altlinux.org>
    This file is part of the VoiceMan speech service.
 
    VoiceMan speech service is free software; you can redistribute it and/or
@@ -112,7 +112,7 @@ void MainLoop::run(const SocketList& sockets, sigset_t* sigMask)
 	    continue;
 	  std::string data;
 	  bool toClose=0;
-	  size_t readBytes = (*clientIt)->socket->read(data);
+	  ssize_t readBytes = (*clientIt)->socket->read(data);
 	  if (readBytes > 0)
 	    logMsg(LOG_DEBUG, "Read %u bytes from client (fd=%d)", data.length(), fd);
 	  if (readBytes <= 0)//if connection closed or there was reading problem;
