@@ -1,5 +1,5 @@
 /*
-	Copyright (c) 2000-2011 Michael Pozhidaev<msp@altlinux.org>
+	Copyright (c) 2000-2012 Michael Pozhidaev<msp@altlinux.org>
    This file is part of the VoiceMan speech service.
 
    VoiceMan speech service is free software; you can redistribute it and/or
@@ -502,7 +502,9 @@ char processInputCommand(int fd)
       maxQueueSize = header.param1;
       return 1;
     } /*COMMAND_SET_QUEUE_LIMIT*/
-  fprintf(stderr, "%s unknown command %X(%lu,%lu,%lu)\n", ERROR_PREFIX, header.code, header.param1, header.param2, header.param3);
+  fprintf(stderr, "%s unknown command %X(%zu,%zu,%zu)\n", ERROR_PREFIX,
+	  header.code, header.param1,
+	  header.param2, header.param3);
   fflush(stderr);
   return 1;
 }
