@@ -1,5 +1,5 @@
 /*
-	Copyright (c) 2000-2011 Michael Pozhidaev<msp@altlinux.org>
+	Copyright (c) 2000-2012 Michael Pozhidaev<msp@altlinux.org>
    This file is part of the VoiceMan speech service.
 
    VoiceMan speech service is free software; you can redistribute it and/or
@@ -270,7 +270,7 @@ vm_result_t vm_tone(vm_connection_t con, size_t freq, size_t lengthms)
   assert(con != VOICEMAN_BAD_CONNECTION);
   if (con == VOICEMAN_BAD_CONNECTION)
     return VOICEMAN_ERROR;
-  sprintf(buf, "B:%lu:%lu\n", freq, lengthms);
+  sprintf(buf, "B:%zu:%zu\n", freq, lengthms);
   if (writebuf(con, buf, strlen(buf)) == -1)
     return VOICEMAN_ERROR;
   return VOICEMAN_OK;
