@@ -1,5 +1,5 @@
 /*
-	Copyright (c) 2000-2011 Michael Pozhidaev<msp@altlinux.org>
+	Copyright (c) 2000-2012 Michael Pozhidaev<msp@altlinux.org>
    This file is part of the VoiceMan speech service.
 
    VoiceMan speech service is free software; you can redistribute it and/or
@@ -76,14 +76,12 @@ bool CmdArgsParser::used(const std::string& name) const
 const std::string CmdArgsParser::operator[](const std::string& name) const
 {
   assert(used(name));
-  for(UsedParamVector::size_type i = 0;i < m_usedParams.size();i++)
-    {
-      if (m_usedParams[i].name != name)
-	continue;
-      assert(m_usedParams[i].hasValue);
-      return m_usedParams[i].value;
-    }
-  assert(false);
+  UsedParamVector::size_type i;
+  for(i = 0; i < m_usedParams.size(); i++)
+    if (m_usedParams[i].name == name)
+      break;
+  assert(i < m_usedParams.size() && m_usedParams[i].hasValue);
+  return m_usedParams[i].value;
 }
 
 /*
